@@ -74,17 +74,16 @@ pub trait Mention<T> {
     fn mention(&self) -> MentionFormat<T>;
 }
 
-/// Mention a channel ID. This will format as `<#ID>`.
-impl Mention<ChannelId> for ChannelId {
-    fn mention(&self) -> MentionFormat<ChannelId> {
-        MentionFormat(*self)
+impl<T, M: Mention<T>> Mention<T> for &'_ M {
+    fn mention(&self) -> MentionFormat<T> {
+        (*self).mention()
     }
 }
 
 /// Mention a channel ID. This will format as `<#ID>`.
-impl Mention<ChannelId> for &'_ ChannelId {
+impl Mention<ChannelId> for ChannelId {
     fn mention(&self) -> MentionFormat<ChannelId> {
-        (*self).mention()
+        MentionFormat(*self)
     }
 }
 
@@ -95,13 +94,6 @@ impl Mention<ChannelId> for CategoryChannel {
     }
 }
 
-/// Mention a guild category channel. This will format as `<#ID>`.
-impl Mention<ChannelId> for &'_ CategoryChannel {
-    fn mention(&self) -> MentionFormat<ChannelId> {
-        (*self).mention()
-    }
-}
-
 /// Mention a channel. This will format as `<#ID>`.
 impl Mention<ChannelId> for Channel {
     fn mention(&self) -> MentionFormat<ChannelId> {
@@ -109,13 +101,6 @@ impl Mention<ChannelId> for Channel {
     }
 }
 
-/// Mention a channel. This will format as `<#ID>`.
-impl Mention<ChannelId> for &'_ Channel {
-    fn mention(&self) -> MentionFormat<ChannelId> {
-        (*self).mention()
-    }
-}
-
 /// Mention the current user. This will format as `<@ID>`.
 impl Mention<UserId> for CurrentUser {
     fn mention(&self) -> MentionFormat<UserId> {
@@ -123,13 +108,6 @@ impl Mention<UserId> for CurrentUser {
     }
 }
 
-/// Mention the current user. This will format as `<@ID>`.
-impl Mention<UserId> for &'_ CurrentUser {
-    fn mention(&self) -> MentionFormat<UserId> {
-        (*self).mention()
-    }
-}
-
 /// Mention an emoji. This will format as `<:emoji:ID>`.
 impl Mention<EmojiId> for EmojiId {
     fn mention(&self) -> MentionFormat<EmojiId> {
@@ -137,13 +115,6 @@ impl Mention<EmojiId> for EmojiId {
     }
 }
 
-/// Mention an emoji. This will format as `<:emoji:ID>`.
-impl Mention<EmojiId> for &'_ EmojiId {
-    fn mention(&self) -> MentionFormat<EmojiId> {
-        (*self).mention()
-    }
-}
-
 /// Mention an emoji. This will format as `<:emoji:ID>`.
 impl Mention<EmojiId> for Emoji {
     fn mention(&self) -> MentionFormat<EmojiId> {
@@ -151,13 +122,6 @@ impl Mention<EmojiId> for Emoji {
     }
 }
 
-/// Mention an emoji. This will format as `<:emoji:ID>`.
-impl Mention<EmojiId> for &'_ Emoji {
-    fn mention(&self) -> MentionFormat<EmojiId> {
-        (*self).mention()
-    }
-}
-
 /// Mention a group. This will format as `<#ID>`.
 impl Mention<ChannelId> for Group {
     fn mention(&self) -> MentionFormat<ChannelId> {
@@ -165,13 +129,6 @@ impl Mention<ChannelId> for Group {
     }
 }
 
-/// Mention a group. This will format as `<#ID>`.
-impl Mention<ChannelId> for &'_ Group {
-    fn mention(&self) -> MentionFormat<ChannelId> {
-        (*self).mention()
-    }
-}
-
 /// Mention a guild channel. This will format as `<#ID>`.
 impl Mention<ChannelId> for GuildChannel {
     fn mention(&self) -> MentionFormat<ChannelId> {
@@ -179,13 +136,6 @@ impl Mention<ChannelId> for GuildChannel {
     }
 }
 
-/// Mention a guild channel. This will format as `<#ID>`.
-impl Mention<ChannelId> for &'_ GuildChannel {
-    fn mention(&self) -> MentionFormat<ChannelId> {
-        (*self).mention()
-    }
-}
-
 /// Mention a member's user. This will format as `<@ID>`.
 impl Mention<UserId> for Member {
     fn mention(&self) -> MentionFormat<UserId> {
@@ -193,13 +143,6 @@ impl Mention<UserId> for Member {
     }
 }
 
-/// Mention a member's user. This will format as `<@ID>`.
-impl Mention<UserId> for &'_ Member {
-    fn mention(&self) -> MentionFormat<UserId> {
-        (*self).mention()
-    }
-}
-
 /// Mention a private channel. This will format as `<#ID>`.
 impl Mention<ChannelId> for PrivateChannel {
     fn mention(&self) -> MentionFormat<ChannelId> {
@@ -207,13 +150,6 @@ impl Mention<ChannelId> for PrivateChannel {
     }
 }
 
-/// Mention a private channel. This will format as `<#ID>`.
-impl Mention<ChannelId> for &'_ PrivateChannel {
-    fn mention(&self) -> MentionFormat<ChannelId> {
-        (*self).mention()
-    }
-}
-
 /// Mention a role ID. This will format as `<@&ID>`.
 impl Mention<RoleId> for RoleId {
     fn mention(&self) -> MentionFormat<RoleId> {
@@ -221,13 +157,6 @@ impl Mention<RoleId> for RoleId {
     }
 }
 
-/// Mention a role ID. This will format as `<@&ID>`.
-impl Mention<RoleId> for &'_ RoleId {
-    fn mention(&self) -> MentionFormat<RoleId> {
-        (*self).mention()
-    }
-}
-
 /// Mention a role ID. This will format as `<@&ID>`.
 impl Mention<RoleId> for Role {
     fn mention(&self) -> MentionFormat<RoleId> {
@@ -235,13 +164,6 @@ impl Mention<RoleId> for Role {
     }
 }
 
-/// Mention a role ID. This will format as `<@&ID>`.
-impl Mention<RoleId> for &'_ Role {
-    fn mention(&self) -> MentionFormat<RoleId> {
-        (*self).mention()
-    }
-}
-
 /// Mention a guild text channel. This will format as `<#ID>`.
 impl Mention<ChannelId> for TextChannel {
     fn mention(&self) -> MentionFormat<ChannelId> {
@@ -249,13 +171,6 @@ impl Mention<ChannelId> for TextChannel {
     }
 }
 
-/// Mention a guild text channel. This will format as `<#ID>`.
-impl Mention<ChannelId> for &'_ TextChannel {
-    fn mention(&self) -> MentionFormat<ChannelId> {
-        (*self).mention()
-    }
-}
-
 /// Mention a user ID. This will format as `<&ID>`.
 impl Mention<UserId> for UserId {
     fn mention(&self) -> MentionFormat<UserId> {
@@ -263,13 +178,6 @@ impl Mention<UserId> for UserId {
     }
 }
 
-/// Mention a user ID. This will format as `<&ID>`.
-impl Mention<UserId> for &'_ UserId {
-    fn mention(&self) -> MentionFormat<UserId> {
-        (*self).mention()
-    }
-}
-
 /// Mention a user. This will format as `<&ID>`.
 impl Mention<UserId> for User {
     fn mention(&self) -> MentionFormat<UserId> {
@@ -277,13 +185,6 @@ impl Mention<UserId> for User {
     }
 }
 
-/// Mention a user. This will format as `<&ID>`.
-impl Mention<UserId> for &'_ User {
-    fn mention(&self) -> MentionFormat<UserId> {
-        (*self).mention()
-    }
-}
-
 /// Mention a guild voice channel. This will format as `<#ID>`.
 impl Mention<ChannelId> for VoiceChannel {
     fn mention(&self) -> MentionFormat<ChannelId> {
@@ -291,13 +192,6 @@ impl Mention<ChannelId> for VoiceChannel {
     }
 }
 
-/// Mention a guild voice channel. This will format as `<#ID>`.
-impl Mention<ChannelId> for &'_ VoiceChannel {
-    fn mention(&self) -> MentionFormat<ChannelId> {
-        (*self).mention()
-    }
-}
-
 #[cfg(test)]
 mod tests {
     use super::{Mention, MentionFormat};
